@@ -2,6 +2,7 @@
 
 use {
     custom_error::custom_error,
+    image::error::ImageError,
     regex,
     std::io,
 };
@@ -11,6 +12,7 @@ custom_error! {pub ProgramError
     Crossterm {source: crossterm::ErrorKind} = "Crossterm Error : {:?}",
     Termimad {source: termimad::Error} = "Termimad Error : {:?}",
     Conf {source: ConfError} = "Bad configuration: {}",
+    ConfFile {path:String, details: ConfError} = "Bad configuration file {:?} : {}",
     ArgParse {bad: String, valid: String} = "{:?} can't be parsed (valid values: {:?})",
     UnknownVerb {name: String} = "No verb matches {:?}",
     AmbiguousVerbName {name: String} = "Ambiguous name: More than one verb matches {:?}",
@@ -23,6 +25,10 @@ custom_error! {pub ProgramError
     InvalidGlobError {pattern: String} = "Invalid glob: {pattern}",
     Unrecognized {token: String} = "Unrecognized: {token}",
     NetError {source: NetError} = "{}",
+    ImageError {source: ImageError } = "{}",
+    Lfs {details: String} = "Failed to fetch mounts: {}",
+    ZeroLenFile = "File seems empty",
+    UnmappableFile = "File can't be mapped",
 }
 
 custom_error! {pub TreeBuildError
@@ -32,15 +38,21 @@ custom_error! {pub TreeBuildError
 
 custom_error! {pub ConfError
     Io {source: io::Error}                          = "unable to read from the file: {}",
+    UnknownFileExtension { path: String}            = "unexpected file extension in {:?}",
     Toml {source: toml::de::Error}                  = "unable to parse TOML: {}",
+    Hjson {source: deser_hjson::Error}              = "unable to parse Hjson: {}",
+    Invalid                                         = "unexpected conf structure", // not expected
     MissingField {txt: String}                      = "missing field in conf",
     InvalidVerbInvocation {invocation: String}      = "invalid verb invocation: {}",
+    InvalidVerbConf {details: String}               = "invalid verb conf: {}",
     UnknownInternal {verb: String}                  = "not a known internal: {}",
     InvalidSearchMode {details: String}             = "invalid search mode: {}",
     InvalidKey {raw: String}                        = "not a valid key: {}",
     ReservedKey {key: String}                       = "reserved key: {}",
     UnexpectedInternalArg {invocation: String}      = "unexpected argument for internal: {}",
     InvalidCols {details: String}                   = "invalid cols definition: {}",
+    InvalidSkin {source: InvalidSkinError}          = "invalid skin: {}",
+    InvalidThreadsCount { count: usize }            = "invalid threads count: {}",
 }
 
 // error which can be raised when parsing a pattern the user typed
@@ -60,8 +72,8 @@ custom_error! {pub InvalidSkinError
 }
 
 custom_error! {pub NetError
-    SocketNotAvailable { path : String }  = "Can't open socket: {} already exists - consider removing it",
-    Io {source: io::Error}                = "error on the socket: {}",
-    InvalidMessage                        = "invalid message received",
+    SocketNotAvailable { path : String } = "Can't open socket: {} already exists - consider removing it",
+    Io {source: io::Error}               = "error on the socket: {}",
+    InvalidMessage                       = "invalid message received",
 }
 
